/**
 * 字符串类型对象
 */
declare type Recordable<T = any> = Record<string, T>

/**
 * 字符串类型对象（只读）
 */
declare interface ReadonlyRecordable<T = any> {
  readonly [key: string]: T
}

/**
 *  T | null 包装
 */
declare type Nullable<T> = T | null

/**
 * T | Not null 包装
 */
declare type NonNullable<T> = T extends null | undefined ? never : T

declare interface Indexable<T = any> {
  [key: string]: T
}

declare type DeepPartial<T> = {
  [P in keyof T]?: DeepPartial<T[P]>;
}
/**
 * 任意类型的异步函数
 */
declare type AnyPromiseFunction = (...arg: any[]) => PromiseLike<any>

/**
 * 任意类型的普通函数
 */
declare type AnyNormalFunction = (...arg: any[]) => any

/**
 * 任意类型的函数
 */
declare type AnyFunction = AnyNormalFunction | AnyPromiseFunction

/**
 * setTimeout 返回值类型
 */
type TimeoutHandle = ReturnType<typeof setTimeout>

/**
 * setInterval 返回值类型
 */
type IntervalHandle = ReturnType<typeof setInterval>

declare type FormType = 'create' | 'update'
